import uuid

from django.contrib.auth.mixins import LoginRequiredMixin
from django.http import HttpResponseBadRequest
from django.shortcuts import render
from django.views import View
from rest_framework.parsers import FormParser

from core.models import Account
from core.util import logs

log = logs.get_logger(__name__)


def get_positions(user, account_id=None):
    items = []
    accounts = Account.objects.filter(user=user)
    for account in accounts:
        positions = account.client.get_all_positions()

        for item in positions:
            items.append(item)
    return items


class Positions(LoginRequiredMixin, View):
    allowed_types = ["modal", "widget", "window", "page"]
    window_content = "window-content/objects.html"
    list_template = "partials/position-list.html"
    page_title = "Live positions from all exchanges"
    page_subtitle = "Manual trades are editable under 'Bot Trades' tab."

    async def get(self, request, type, account_id=None):
        if type not in self.allowed_types:
            return HttpResponseBadRequest
        template_name = f"wm/{type}.html"
        unique = str(uuid.uuid4())[:8]
        items = get_positions(request.user, account_id)
        print("ITEMS", items)
        if type == "page":
            type = "modal"
        context = {
            "title": f"Hooks ({type})",
            "unique": unique,
            "window_content": self.window_content,
            "list_template": self.list_template,
            "items": items,
            "type": type,
            "page_title": self.page_title,
            "page_subtitle": self.page_subtitle,
        }
        return render(request, template_name, context)


class PositionAction(LoginRequiredMixin, View):
    allowed_types = ["modal", "widget", "window", "page"]
    window_content = "window-content/view-position.html"
    parser_classes = [FormParser]

    async def get(self, request, type, account_id, symbol):
        """
        Get live information for a trade.
        """
        if type not in self.allowed_types:
            return HttpResponseBadRequest
        template_name = f"wm/{type}.html"
        unique = str(uuid.uuid4())[:8]

        account = Account.get_by_id(account_id, request.user)
        info = account.client.get_position_info(symbol)
        print("ACCT INFO", info)

        items = get_positions(request.user, account_id)
        if type == "page":
            type = "modal"
        context = {
            "title": f"Hooks ({type})",
            "unique": unique,
            "window_content": self.window_content,
            "items": items,
            "type": type,
        }
        context["items"] = info

        return render(request, template_name, context)
